/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global window, tizen, console*/

/**
 * Systeminfo module.
 *
 * @module app.systeminfo
 * @namespace app.systeminfo
 * @memberof app
 */

window.app = window.app || {};

(function defineSysteminfo(app) {
    'use strict';

    /**
     * Application systeminfo module reference.
     *
     * @private
     * @type {Module}
     */
    var systeminfo = null;

    // create namespace for the module
    app.systeminfo = app.systeminfo || {};
    systeminfo = app.systeminfo;

    /**
     * Closes application.
     *
     * @memberof app.systeminfo
     * @public
     */
    systeminfo.exit = function exit() {
        try {
            tizen.application.getCurrentApplication().exit();
        } catch (err) {
            console.error('Error: ', err.message);
        }
    };

    /**
     * Adds listener for battery change to low.
     *
     * @memberof app.systeminfo
     * @private
     */
    function listenBatteryLowState() {
        try {
            tizen.systeminfo.addPropertyValueChangeListener(
                'BATTERY',
                function change(battery) {
                    if (!battery.isCharging) {
                        systeminfo.exit();
                    }
                },
                {
                    lowThreshold: 0.04
                },
                function onError(err) {
                    console.error('Error: ', err.message);
                }
            );
        } catch (err) {
            console.error('Error: ', err.message);
        }
    }

    /**
     * Checks low battery state.
     *
     * @memberof app.systeminfo
     * @private
     */
    function checkBatteryLowState() {
        try {
            tizen.systeminfo.getPropertyValue('BATTERY',
                function onGetBatteryInfo(battery) {
                    if (battery.level < 0.04 && !battery.isCharging) {
                        systeminfo.exit();
                    }
                }, null);
        } catch (err) {
            console.error('Error: ', err.message);
        }
    }

    /**
     * Initializes the module.
     *
     * @memberof app.systeminfo
     * @public
     */
    systeminfo.init = function init() {
        if (tizen !== null &&
            typeof tizen === 'object' &&
            tizen.systeminfo !== null &&
            typeof tizen.systeminfo === 'object') {
            checkBatteryLowState();
            listenBatteryLowState();
        } else {
            console.warn(
                'tizen.systeminfo not available'
            );
        }
    };
})(window.app);
